@@ -807,7 +807,16 @@ appearance_settings_dialog_channel_property_changed (XfconfChannel *channel,
         gsettings = g_settings_new (gsettings_category_gnome_interface);
         if (gsettings)
         {
-            g_settings_set_string (gsettings, "gtk-theme", xfconf_channel_get_string (channel, property_name, NULL));
+            str = xfconf_channel_get_string (channel, property_name, NULL);
+            g_settings_set_string (gsettings, "gtk-theme", str);
+
+            /* Also set the preferred color scheme (needed for GTK4) */
+            if (str != NULL && g_str_has_suffix (str, "-dark"))
+                g_settings_set_string (gsettings, "color-scheme", "prefer-dark");
+            else
+                g_settings_reset (gsettings, "color-scheme");
+
+            g_free (str);
         }
     }
     else if (strcmp (property_name, "/Net/IconThemeName") == 0)
@@ -855,7 +864,9 @@ appearance_settings_dialog_channel_property_changed (XfconfChannel *channel,
         gsettings = g_settings_new (gsettings_category_gnome_interface);
         if (gsettings)
         {
-            g_settings_set_string (gsettings, "icon-theme", xfconf_channel_get_string (channel, property_name, NULL));
+            str = xfconf_channel_get_string (channel, property_name, NULL);
+            g_settings_set_string (gsettings, "icon-theme", str);
+            g_free (str);
         }
     }
     else if (strcmp (property_name, "/Gtk/FontName") == 0)
@@ -864,7 +875,9 @@ appearance_settings_dialog_channel_property_changed (XfconfChannel *channel,
         gsettings = g_settings_new (gsettings_category_gnome_interface);
         if (gsettings)
         {
-            g_settings_set_string (gsettings, "font-name", xfconf_channel_get_string (channel, property_name, NULL));
+            str = xfconf_channel_get_string (channel, property_name, NULL);
+            g_settings_set_string (gsettings, "font-name", str);
+            g_free (str);
         }
     }
     else if (strcmp (property_name, "/Gtk/MonospaceFontName") == 0)
@@ -873,7 +886,9 @@ appearance_settings_dialog_channel_property_changed (XfconfChannel *channel,
         gsettings = g_settings_new (gsettings_category_gnome_interface);
         if (gsettings)
         {
-            g_settings_set_string (gsettings, "monospace-font-name", xfconf_channel_get_string (channel, property_name, NULL));
+            str = xfconf_channel_get_string (channel, property_name, NULL);
+            g_settings_set_string (gsettings, "monospace-font-name", str);
+            g_free (str);
         }
     }
 }
